@@ -13,7 +13,7 @@ from sqlglot.dialects.dialect import (
     no_safe_divide_sql,
     no_trycast_sql,
     rename_func,
-    strposition_to_local_sql,
+    strposition_to_locate_sql,
     struct_extract_sql,
     timestrtotime_sql,
     var_map_sql,
@@ -297,7 +297,7 @@ class Hive(Dialect):
             exp.SchemaCommentProperty: lambda self, e: self.naked_property(e),
             exp.SetAgg: rename_func("COLLECT_SET"),
             exp.Split: lambda self, e: f"SPLIT({self.sql(e, 'this')}, CONCAT('\\\\Q', {self.sql(e, 'expression')}))",
-            exp.StrPosition: strposition_to_local_sql,
+            exp.StrPosition: strposition_to_locate_sql,
             exp.StrToDate: _str_to_date,
             exp.StrToTime: _str_to_time,
             exp.StrToUnix: _str_to_unix,
